@@ -124,13 +124,6 @@ public:
     */
     TransportType transportType() const;
 
-    /**
-      Sets the type of this transport.
-      @see TransportType.
-      @since 4.4
-    */
-    void setTransportType(const TransportType &type);
-
 protected:
     /**
       Creates a Transport object. Should only be used by TransportManager.
@@ -138,8 +131,8 @@ protected:
     */
     Transport(const QString &cfgGroup);
 
-    void usrRead() Q_DECL_OVERRIDE;
-    bool usrSave() Q_DECL_OVERRIDE;
+    void usrRead() override;
+    bool usrSave() override;
 
     /**
       Returns true if the password was not stored in the wallet.
