@@ -48,15 +48,11 @@ public:
     /** Destroys this object. */
     virtual ~SendQueuedAction();
 
-    Akonadi::ItemFetchScope fetchScope() const Q_DECL_OVERRIDE;
+    Akonadi::ItemFetchScope fetchScope() const override;
 
-    bool itemAccepted(const Akonadi::Item &item) const Q_DECL_OVERRIDE;
+    bool itemAccepted(const Akonadi::Item &item) const override;
 
-    Akonadi::Job *itemAction(const Akonadi::Item &item, Akonadi::FilterActionJob *parent) const Q_DECL_OVERRIDE;
-
-private:
-    class Private;
-    Private *const d;
+    Akonadi::Job *itemAction(const Akonadi::Item &item, Akonadi::FilterActionJob *parent) const override;
 };
 
 /**
@@ -79,15 +75,11 @@ public:
     /** Destroys this object. */
     virtual ~ClearErrorAction();
 
-    Akonadi::ItemFetchScope fetchScope() const Q_DECL_OVERRIDE;
+    Akonadi::ItemFetchScope fetchScope() const override;
 
-    bool itemAccepted(const Akonadi::Item &item) const Q_DECL_OVERRIDE;
+    bool itemAccepted(const Akonadi::Item &item) const override;
 
-    virtual Akonadi::Job *itemAction(const Akonadi::Item &item, Akonadi::FilterActionJob *parent) const Q_DECL_OVERRIDE;
-
-private:
-    class Private;
-    Private *const d;
+    virtual Akonadi::Job *itemAction(const Akonadi::Item &item, Akonadi::FilterActionJob *parent) const override;
 };
 
 /**
@@ -108,16 +100,13 @@ public:
 
     virtual ~DispatchManualTransportAction();
 
-    Akonadi::ItemFetchScope fetchScope() const Q_DECL_OVERRIDE;
+    Akonadi::ItemFetchScope fetchScope() const override;
 
-    bool itemAccepted(const Akonadi::Item &item) const Q_DECL_OVERRIDE;
+    bool itemAccepted(const Akonadi::Item &item) const override;
 
-    virtual Akonadi::Job *itemAction(const Akonadi::Item &item, Akonadi::FilterActionJob *parent) const Q_DECL_OVERRIDE;
+    virtual Akonadi::Job *itemAction(const Akonadi::Item &item, Akonadi::FilterActionJob *parent) const override;
 
 private:
-    class Private;
-    Private *const d;
-
     int mTransportId;
 };
 } // namespace MailTransport
